@@ -8,28 +8,13 @@ class BertRelationExtrac(BasicBert):
     """
     """
     def __init__(self, word2ix, predicate_num, model_name="roberta"):
-        super(BertRelationExtrac, self).__init__()
+        super(BertRelationExtrac, self).__init__(word2ix=word2ix, model_name=model_name)
         
-        self.predicate_num = predicate_num 
-        config = ""
-        if model_name == "roberta":
-            from bert_seq2seq.model.roberta_model import BertModel, BertConfig, BertPredictionHeadTransform, BertLayerNorm
-            config = BertConfig(len(word2ix))
-            self.bert = BertModel(config)
-            self.layer_norm = BertLayerNorm(config.hidden_size)
-            self.layer_norm_cond = BertLayerNorm(config.hidden_size, conditional=True)
-        elif model_name == "bert":
-            from bert_seq2seq.model.bert_model import BertConfig, BertModel, BertPredictionHeadTransform, BertLayerNorm
-            config = BertConfig(len(word2ix))
-            self.bert = BertModel(config)
-            self.layer_norm = BertLayerNorm(config.hidden_size)
-            self.layer_norm_cond = BertLayerNorm(config.hidden_size, conditional=True)
-        else :
-            raise Exception("model_name_err")
+        self.predicate_num = predicate_num
         
-        self.subject_pred = nn.Linear(config.hidden_size, 2)
+        self.subject_pred = nn.Linear(self.config.hidden_size, 2)
         self.activation = nn.Sigmoid()
-        self.object_pred = nn.Linear(config.hidden_size, 2 * self.predicate_num)
+        self.object_pred = nn.Linear(self.config.hidden_size, 2 * self.predicate_num)
     
     def binary_crossentropy(self, labels, pred):
         labels = labels.float()
